@@ -38,12 +38,20 @@ import (
 
 type TestOpt func(*IntegrationTestConfig)
 
+// TestOptRunning will enable running in integration tests.
 func TestOptRunning() TestOpt {
 	return func(c *IntegrationTestConfig) {
 		c.Running = true
 	}
 }
 
+// TestOptWatching will enable watching in integration tests.
+func TestOptWatching() TestOpt {
+	return func(c *IntegrationTestConfig) {
+		c.Watching = true
+	}
+}
+
 // Enable tracing in integration tests.
 // THis should only be used during development and not committed to the repo.
 func TestOptTrace() TestOpt {
@@ -198,24 +206,34 @@ func (b *lockingBuffer) Write(p []byte) (n int, err error) {
 	return
 }
 
+// AssertLogContains asserts that the last build log contains the given strings.
+// Each string can be negated with a "! " prefix.
 func (s *IntegrationTestBuilder) AssertLogContains(els ...string) {
 	s.Helper()
 	for _, el := range els {
-		s.Assert(s.lastBuildLog, qt.Contains, el)
-	}
-}
-
-func (s *IntegrationTestBuilder) AssertLogNotContains(els ...string) {
-	s.Helper()
-	for _, el := range els {
-		s.Assert(s.lastBuildLog, qt.Not(qt.Contains), el)
+		var negate bool
+		el, negate = s.negate(el)
+		check := qt.Contains
+		if negate {
+			check = qt.Not(qt.Contains)
+		}
+		s.Assert(s.lastBuildLog, check, el)
 	}
 }
 
+// AssertLogNotContains asserts that the last build log does matches the given regular expressions.
+// The regular expressions can be negated with a "! " prefix.
 func (s *IntegrationTestBuilder) AssertLogMatches(expression string) {
 	s.Helper()
+	var negate bool
+	expression, negate = s.negate(expression)
 	re := regexp.MustCompile(expression)
-	s.Assert(re.MatchString(s.lastBuildLog), qt.IsTrue, qt.Commentf(s.lastBuildLog))
+	checker := qt.IsTrue
+	if negate {
+		checker = qt.IsFalse
+	}
+
+	s.Assert(re.MatchString(s.lastBuildLog), checker, qt.Commentf(s.lastBuildLog))
 }
 
 func (s *IntegrationTestBuilder) AssertBuildCountData(count int) {
@@ -250,6 +268,15 @@ func (s *IntegrationTestBuilder) AssertFileCount(dirname string, expected int) {
 	s.Assert(count, qt.Equals, expected)
 }
 
+func (s *IntegrationTestBuilder) negate(match string) (string, bool) {
+	var negate bool
+	if strings.HasPrefix(match, "! ") {
+		negate = true
+		match = strings.TrimPrefix(match, "! ")
+	}
+	return match, negate
+}
+
 func (s *IntegrationTestBuilder) AssertFileContent(filename string, matches ...string) {
 	s.Helper()
 	content := strings.TrimSpace(s.FileContent(filename))
@@ -262,10 +289,7 @@ func (s *IntegrationTestBuilder) AssertFileContent(filename string, matches ...s
 				continue
 			}
 			var negate bool
-			if strings.HasPrefix(match, "! ") {
-				negate = true
-				match = strings.TrimPrefix(match, "! ")
-			}
+			match, negate = s.negate(match)
 			if negate {
 				s.Assert(content, qt.Not(qt.Contains), match, cm)
 				continue
@@ -397,6 +421,12 @@ func (s *IntegrationTestBuilder) Build() *IntegrationTestBuilder {
 		s.Assert(err, qt.IsNil)
 	}
 
+	s.Cleanup(func() {
+		if h := s.H; h != nil {
+			s.Assert(h.Close(), qt.IsNil)
+		}
+	})
+
 	return s
 }
 
@@ -570,6 +600,10 @@ func (s *IntegrationTestBuilder) initBuilder() error {
 				"running": s.Cfg.Running,
 				"watch":   s.Cfg.Running,
 			})
+		} else if s.Cfg.Watching {
+			flags.Set("internal", maps.Params{
+				"watch": s.Cfg.Watching,
+			})
 		}
 
 		if s.Cfg.WorkingDir != "" {
@@ -631,7 +665,7 @@ func (s *IntegrationTestBuilder) initBuilder() error {
 			sc := security.DefaultConfig
 			sc.Exec.Allow, err = security.NewWhitelist("npm")
 			s.Assert(err, qt.IsNil)
-			ex := hexec.New(sc)
+			ex := hexec.New(sc, s.Cfg.WorkingDir)
 			command, err := ex.New("npm", "install")
 			s.Assert(err, qt.IsNil)
 			s.Assert(command.Run(), qt.IsNil)
@@ -817,6 +851,11 @@ type IntegrationTestConfig struct {
 	// Whether to simulate server mode.
 	Running bool
 
+	// Watch for changes.
+	// This is (currently) always set to true when Running is set.
+	// Note that the CLI for the server does allow for --watch=false, but that is not used in these test.
+	Watching bool
+
 	// Will print the log buffer after the build
 	Verbose bool
 
